pub trait RefKv<K, V> {
// Required method
fn ref_kv(&self) -> (&K, &V);
}Expand description
Yields a pair of a references, each of which points to a key and a value.
This trait is used to convert a reference to a pair &(K, V) into a pair of references
(&K, &V).
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".