Subsystem

Struct Subsystem 

pub struct Subsystem { /* private fields */ }
Handler of a Cpuacct subsystem.

Implementations

Source

impl Subsystem

pub fn stat(&self) -> Result<Stat>

Reads the statistics about how much CPU time is consumed by this cgroup (in USER_HZ unit) from cpuacct.stat file. The CPU time is further divided into user and system times.

See the kernel’s documentation for more information about this field.

Errors

Returns an error if failed to read and parse cpuacct.stat file of this cgroup.

Examples
use std::path::PathBuf;
use controlgroup::v1::{cpuacct, Cgroup, CgroupPath, SubsystemKind};

let cgroup = cpuacct::Subsystem::new(
    CgroupPath::new(SubsystemKind::Cpuacct, PathBuf::from("students/charlie")));

let stat = cgroup.stat()?;
pub fn usage(&self) -> Result<u64>

Reads the total CPU time consumed by this cgroup (in nanoseconds) from cpuacct.usage file.

See the kernel’s documentation for more information about this field.

Errors

Returns an error if failed to read and parse cpuacct.usage file of this cgroup.

Examples
use std::path::PathBuf;
use controlgroup::v1::{cpuacct, Cgroup, CgroupPath, SubsystemKind};

let cgroup = cpuacct::Subsystem::new(
    CgroupPath::new(SubsystemKind::Cpuacct, PathBuf::from("students/charlie")));

let usage = cgroup.usage()?;
pub fn usage_all(&self) -> Result<Vec<Stat>>

Reads the per-CPU total CPU time consumed by this cgroup (in nanoseconds) from cpuacct.usage_all file. The CPU time is further divided into user and system times.

See the kernel’s documentation for more information about this field.

Errors

Returns an error if failed to read and parse cpuacct.usage_all file of this cgroup.

Examples
use std::path::PathBuf;
use controlgroup::v1::{cpuacct, Cgroup, CgroupPath, SubsystemKind};

let cgroup = cpuacct::Subsystem::new(
    CgroupPath::new(SubsystemKind::Cpuacct, PathBuf::from("students/charlie")));

let usage_all = cgroup.usage_all()?;
pub fn usage_percpu(&self) -> Result<Vec<u64>>

Reads the per-CPU total CPU times consumed by this cgroup (in nanoseconds) from cpuacct.usage_percpu file.

See the kernel’s documentation for more information about this field.

Errors

Returns an error if failed to read and parse cpuacct.usage_percpu file of this cgroup.

Examples
use std::path::PathBuf;
use controlgroup::v1::{cpuacct, Cgroup, CgroupPath, SubsystemKind};

let cgroup = cpuacct::Subsystem::new(
    CgroupPath::new(SubsystemKind::Cpuacct, PathBuf::from("students/charlie")));

let usage_percpu = cgroup.usage_percpu()?;
pub fn usage_percpu_sys(&self) -> Result<Vec<u64>>

Reads the per-CPU total CPU times consumed by this cgroup in the system (kernel) mode (in nanoseconds) from cpuacct.usage_percpu_sys file.

See the kernel’s documentation for more information about this field.

Errors

Returns an error if failed to read and parse cpuacct.usage_percpu_sys file of this cgroup.

Examples
use std::path::PathBuf;
use controlgroup::v1::{cpuacct, Cgroup, CgroupPath, SubsystemKind};

let cgroup = cpuacct::Subsystem::new(
    CgroupPath::new(SubsystemKind::Cpuacct, PathBuf::from("students/charlie")));

let usage_percpu_sys = cgroup.usage_percpu_sys()?;
pub fn usage_percpu_user(&self) -> Result<Vec<u64>>

Reads the per-CPU total CPU times consumed by this cgroup in the user mode (in nanoseconds) from cpuacct.usage_percpu_user file.

See the kernel’s documentation for more information about this field.

Errors

Returns an error if failed to read and parse cpuacct.usage_percpu_user file of this cgroup.

Examples
use std::path::PathBuf;
use controlgroup::v1::{cpuacct, Cgroup, CgroupPath, SubsystemKind};

let cgroup = cpuacct::Subsystem::new(
    CgroupPath::new(SubsystemKind::Cpuacct, PathBuf::from("students/charlie")));

let usage_percpu_user = cgroup.usage_percpu_user()?;
pub fn usage_sys(&self) -> Result<u64>

Reads the total CPU time consumed by this cgroup in the system (kernel) mode (in nanoseconds) from cpuacct.usage_sys file.

See the kernel’s documentation for more information about this field.

Errors

Returns an error if failed to read and parse cpuacct.usage_sys file of this cgroup.

Examples
use std::path::PathBuf;
use controlgroup::v1::{cpuacct, Cgroup, CgroupPath, SubsystemKind};

let cgroup = cpuacct::Subsystem::new(
    CgroupPath::new(SubsystemKind::Cpuacct, PathBuf::from("students/charlie")));

let usage_sys = cgroup.usage_sys()?;
pub fn usage_user(&self) -> Result<u64>

Reads the total CPU time consumed by this cgroup in the user mode (in nanoseconds) from cpuacct.usage_user file.

See the kernel’s documentation for more information about this field.

Errors

Returns an error if failed to read and parse cpuacct.usage_user file of this cgroup.

Examples
use std::path::PathBuf;
use controlgroup::v1::{cpuacct, Cgroup, CgroupPath, SubsystemKind};

let cgroup = cpuacct::Subsystem::new(
    CgroupPath::new(SubsystemKind::Cpuacct, PathBuf::from("students/charlie")));

let usage_user = cgroup.usage_user()?;
pub fn reset(&mut self) -> Result<()>

Resets the accounted CPU time of this cgroup by writing to cpuacct.usage file.

Errors

Returns an error if failed to write to cpuacct.usage file of this cgroup.

Examples
use std::path::PathBuf;
use controlgroup::v1::{cpuacct, Cgroup, CgroupPath, SubsystemKind};

let mut cgroup = cpuacct::Subsystem::new(
    CgroupPath::new(SubsystemKind::Cpuacct, PathBuf::from("students/charlie")));

cgroup.reset()?;